{%- extends "basic/layout.html" %}

{# This block is not used. #}
{%- block header %}{% endblock %}
{%- block relbar1 %}{% endblock %}
{%- block relbar2 %}{% endblock %}
{%- block footer %}{% endblock %}
